#!/bin/bash

BOOT_DIR="./boot"
ROOTFS_DIR="./rootfs"

function check_user()
{
    if [ `whoami` != root ]; then
	echo "this utility must be run from root or using sudo!"
	exit 1
    fi
}

function usage()
{
    echo "This utility mount sd image file to boot and rootfs directory."
    echo "Usage:"
    echo "  $0 <image name> "
    echo "Example:"
    echo "  $0 sd.img"
}


function check_args()
{
    echo $#
    if [ $# -ne 1 ]; then
        usage
        exit 1
    fi
    IMG_FILE=$1
    
    if ! [[ -e ${IMG_FILE} ]]; then
        echo "image file not found at ${IMG_FILE}! Quitting..."
        exit 1
    fi

    if ! [[ -d ${BOOT_DIR} ]]; then
	echo "boot dir not found at ${BOOT_DIR}! Quitting..."
        exit 1
    fi
    if ! [[ -d ${ROOTFS_DIR} ]]; then
	echo "rootfs dir not found at ${ROOTFS_DIR}! Quitting..."
        exit 1
    fi
}

function make_image()
{    
    # Reverse-engineer the partition setup
    BYTES_PER_SECTOR="$(/sbin/fdisk -l -u ${IMG_FILE} | grep Units | awk '{print $9}')"
    VFAT_SECTOR_OFFSET="$(/sbin/fdisk -l -u ${IMG_FILE} | grep img1 | awk '{print $3}')"
    VFAT_SECTOR_OFFSET=$(expr ${BYTES_PER_SECTOR} "*" ${VFAT_SECTOR_OFFSET})
    echo "VFAT_SECTOR_OFFSET=${VFAT_SECTOR_OFFSET}"
    EXT3_SECTOR_OFFSET="$(/sbin/fdisk -l -u ${IMG_FILE} | grep img2 | awk '{print $2}')"
    EXT3_SECTOR_OFFSET=$(expr ${BYTES_PER_SECTOR} "*" ${EXT3_SECTOR_OFFSET})
    echo "EXT3_SECTOR_OFFSET=${EXT3_SECTOR_OFFSET}"


    echo "mount boot partition at ${BOOT_DIR}..."
    
    mount -t vfat -o loop,sync,offset=${VFAT_SECTOR_OFFSET}  ${IMG_FILE}  ${BOOT_DIR} 

    echo "mount rootfs partition at ${ROOTFS_DIR}..."
    mount -t ext3 -o loop,sync,offset=${EXT3_SECTOR_OFFSET}  ${IMG_FILE}  ${ROOTFS_DIR}
}

#ARGS=$*
ARGS="./sd.img"
check_user
check_args $ARGS
make_image


